@@ -21,7 +21,8 @@ logger.addHandler(handler)
 description = """Calculate GW detector inspiral range from ASD/PSD
 
 Strain spectra data should be two-column ASCII, (freq, strain), and
-may be given in amplitude or power (ASD or PSD).
+may be given in amplitude or power (ASD or PSD).  The --divisor option
+can be used to specify a scalar converstion for e.g. meters to strain.
 
 Inspiral waveform parameters are specified as PARAM=VALUE pairs.  Mass
 ('m1'/'m2') parameters are assumed to be in solar masses (Msolar)
@@ -73,6 +74,9 @@ igroup.add_argument(
 igroup.add_argument(
     '-p', '--psd', action=FileAction,
     help="assume noise spectrum is PSD")
+parser.add_argument(
+    '-d', '--divisor', default=1, type=float,
+    help="factor to divide PSD (e.g. convert displacement to strain)")
 ogroup = parser.add_mutually_exclusive_group()
 ogroup.add_argument(
     '-f', '--format', dest='fmt', choices=['txt', 'json', 'yaml'], default='txt',
@@ -97,6 +101,7 @@ def main():
     data = np.loadtxt(args.file)
     freq = data[1:, 0]
     psd = data[1:, 1]
+    psd /= args.divisor
     if args.stype == 'asd':
         psd **= 2
 
@@ -126,24 +131,41 @@ def main():
 
     if args.plot:
         import matplotlib.pyplot as plt
+        from matplotlib.gridspec import GridSpec
         import signal
         signal.signal(signal.SIGINT, signal.SIG_DFL)
-        dlum = metrics['horizon'][0]
+        dlum = metrics['range'][0]
         z = inspiral_range.horizon_redshift(freq, psd, H=H)
         hfreq, habs = H.z_scale(z)
-        label = r"{} {}/{} $\mathrm{{M}}_\odot$ {:0.0f} Mpc".format(
+        int73 = inspiral_range.sensemon_range(freq, psd, integrate=False)
+
+        label = r"{} {}/{} $\mathrm{{M}}_\odot$ @ {:0.0f} Mpc".format(
             H.params['approximant'],
             H.params['m1'], H.params['m2'],
             dlum,
         )
-        plt.loglog(freq, np.sqrt(psd), label="strain noise")
+
+        fig = plt.figure()
+        gs = GridSpec(2, 1, height_ratios=(2, 1), hspace=0)
+        ax0 = fig.add_subplot(gs[0])
+        ax1 = fig.add_subplot(gs[1])
+        ax1.sharex(ax0)
+        ax0.loglog(freq, np.sqrt(psd), label="strain noise ASD")
         # put waveform in same units as noise strain
-        plt.loglog(hfreq, habs*2*np.sqrt(hfreq), linestyle='--', label=label)
-        plt.grid()
-        plt.ylabel(u"Strain [1/\u221AHz]")
-        plt.xlabel("Frequency [Hz]")
-        plt.title(f"{args.file}")
-        plt.legend()
+        ax0.loglog(hfreq, habs*2*np.sqrt(hfreq), linestyle='--', label=label)
+        ax1.semilogx(freq, int73, label="sensemon range ASD")
+        ax1.grid()
+        ax0.grid()
+        ax0.set_title(f"{args.file}")
+        ax0.set_ylabel(u"Strain [1/\u221AHz]")
+        ax0.tick_params(labelbottom=False)
+        ax1.set_ylabel(u"Range [Mpc/\u221AHz]")
+        ax1.set_xlabel("Frequency [Hz]")
+        ax0.legend()
+        ax1.legend()
+        # h0, l0 = ax0.get_legend_handles_labels()
+        # h1, l1 = ax1.get_legend_handles_labels()
+        # ax0.legend(h0+h1, l0+l1)
         plt.show()
 
 ##################################################
